==> haskell-roman-numerals-0.5.1.5-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: roman-numerals
version: 0.5.1.5
id: roman-numerals-0.5.1.5-3vRv1QCyYDK2oRDfXgp87u
key: roman-numerals-0.5.1.5-3vRv1QCyYDK2oRDfXgp87u
license: BSD3
copyright: 2009–2014 Roel van Dijk
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: stable
homepage: https://github.com/roelvandijk/roman-numerals
synopsis: Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.
category: Numerical, Parsing
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Numeral.Roman
abi: 0c9b89469e1be44f0109cad1240b3cf9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/roman-numerals-0.5.1.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/roman-numerals-0.5.1.5
hs-libraries: HSroman-numerals-0.5.1.5-3vRv1QCyYDK2oRDfXgp87u
depends:
    base-4.10.1.0 base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd=d64e813a02a40130dd55942d18e11638
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
haddock-interfaces: /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock
haddock-html: /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-roman-numerals-0.5.1.5-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: roman-numerals
version: 0.5.1.5
id: roman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n
key: roman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n
license: BSD3
copyright: 2009–2014 Roel van Dijk
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: stable
homepage: https://github.com/roelvandijk/roman-numerals
synopsis: Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.
category: Numerical, Parsing
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Numeral.Roman
abi: ef45e39be436eb9a57cf28db0e2e28cd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/roman-numerals-0.5.1.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/roman-numerals-0.5.1.5
hs-libraries: HSroman-numerals-0.5.1.5-ARheSnyRO53Fu09gKbBK7n
depends:
    base-4.10.1.0 base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd=d64e813a02a40130dd55942d18e11638
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock
haddock-html: /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
